[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples

变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
  保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
  async_reduce, custom_temporary_allocation, explicit_cuda_stream,
  global_device_vector, range_view, unwrap_pointer, wrap_pointer, device

结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
  27/27 tuning headers, 78 benchmarks, 243 tests,
  60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
muh-bot
2026-08-03 12:39:26 +00:00
parent a2a5dd8f00
commit 24ef6a91b5
5439 changed files with 0 additions and 719516 deletions

View File

@@ -1,72 +0,0 @@
//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
/**
* @file
*
* @brief Ensure that the scalar data interface works on both stream and graph backends
*
*/
#include <cuda/experimental/stf.cuh>
using namespace cuda::experimental::stf;
void test_shape_from_scalar_view()
{
double x = 0;
scalar_view<double> sv(&x);
shape_of<scalar_view<double>> s = shape(sv);
EXPECT(s.size() == sizeof(double));
size_t n = 0;
scalar_view<size_t> sv_n(&n);
shape_of<scalar_view<size_t>> s_n = shape(sv_n);
EXPECT(s_n.size() == sizeof(size_t));
}
template <typename Ctx>
void run()
{
Ctx ctx;
double a = 42.0;
double b = 12.3;
auto la = ctx.logical_data(scalar_view<double>(&a)).set_symbol("a");
auto lb = ctx.logical_data(scalar_view<double>(&b)).set_symbol("b");
auto lc = ctx.logical_data(shape_of<scalar_view<double>>()).set_symbol("c");
ctx.parallel_for(box(1), la.read(), lb.read(), lc.write())->*[] __device__(size_t, auto a, auto b, auto c) {
*c.addr = *a.addr + *b.addr;
};
ctx.host_launch(lc.read())->*[](auto x) {
EXPECT(fabs(*x.addr - (42.0 + 12.3)) < 0.001);
};
// Exercise logical_data(la.shape()) when la is scalar_view-backed (uses shape_of from scalar_view)
auto ld = ctx.logical_data(la.shape()).set_symbol("d");
ctx.parallel_for(box(1), la.read(), ld.write())->*[] __device__(size_t, auto a, auto d) {
*d.addr = *a.addr;
};
ctx.host_launch(ld.read())->*[](auto x) {
EXPECT(fabs(*x.addr - 42.0) < 0.001);
};
ctx.finalize();
}
int main()
{
test_shape_from_scalar_view();
run<stream_ctx>();
run<graph_ctx>();
}